@@ -2,12 +2,18 @@
 #'
 #' Go from a string to a vector whose \eqn{i}th element is the \eqn{i}th
 #' character in the string.
-#' @param string A string.
+#'
+#' @inheritParams str_after_nth
+#'
 #' @return A character vector.
+#'
 #' @examples
 #' str_to_vec("abcdef")
+#'
+#' @family converters
 #' @export
 str_to_vec <- function(string) {
+  if (all_equal(string, character())) return(character())
   checkmate::assert_character(string)
   strsplit(string, NULL)[[1]]
 }
